@@ -3,6 +3,11 @@ use strict;
 package Synopsis;
 use Package::Autoloader sub{eval shift}, sub {
 	$_[0]->export('::*', ['hello_world']);
+
+	my $yn = q{
+ 		return(q{print STDERR ($_[0] ? 'Yes' : 'No'), "\n";});
+	};
+	$_[0]->register_rule($yn, '*', 'yn');
 };
 
 sub hello_world() { print "Hello World.\n"; };
@@ -10,9 +15,9 @@ sub hello_world() { print "Hello World.\n"; };
 package Synopsis::Ex1;
 use Package::Autoloader sub{eval shift};
 
-print STDOUT (defined(&hello_world) ? 'Can':'Cannot'),"\n";
-print STDOUT (potentially_defined('hello_world') ? 'Can':'Cannot'),"\n";
-
+yn(!defined(&hello_world));
+	yn(potentially_defined('hello_world'));
 hello_world();
+yn(defined(&hello_world));
 
 exit(0);
